#!/bin/bash

#
# This is the installation script for the Intel C/C++ and Fortran
# compilers, plus the Intel debuggger for Linux. 
# Please read the file INSTALL for instructions on how to install 
# the compilers before using this script.
#

# SELECT AN INSTALL AREA
INSTALLDIR=/home/jjl/test       

# NOW SELECT YOUR ENVIRONMENT: I386, EM64T OR IA64. IF YOU NEED MORE
# THAN ONE, RUN THIS SCRIPT FOR EACH ENVIRONMENT

 ARCH=i386     # i386 users uncomment this line
# ARCH=em64t    # em64t users uncomment this line
# ARCH=ia64     # ia64 users uncomment this line

# NOW SELECT WHETHER YOU NEED C/C++ OR FORTRAN OR BOTH
# USE yes OR no ONLY
INSTALLC=yes
INSTALLF=yes









################################################################
################## DON'T EDIT BELOW THIS LINE ##################
################################################################

# MAKE SURE THE SCRIPT HAS BEEN EDITED PROPERLY

if [ -z $INSTALLDIR ]
then
    echo "You must define the install area in the script!"
    exit 
fi

if [ -z $ARCH ]
then
    echo "You must define the system architecture in the script!"
    exit 
fi

if [ $INSTALLC != "yes" ] && [ $INSTALLF != "yes" ]
then
    echo "You must install at least one of the C/C++ or Fortran compilers"
    exit
fi

# FIND OUT WHICH TAR BALLS WE NEED
if [ $ARCH == i386 ] 
then
    DEBUG=intel-iidb9-9.0-*.i386.tar.gz
    HEADER=intel-isubh9-9.0-*.i386.tar.gz
    ICC=intel-icc9-9.0-*.i386.tar.gz
    FORTRAN=intel-ifort9-9.0-*.i386.tar.gz
elif [ $ARCH = "em64t" ] 
then
    DEBUG=intel-iidbe9-9.0-*.em64t.tar.gz
    HEADER=intel-isubhe9-9.0-*.em64t.tar.gz
    ICC=intel-icce9-9.0-*.em64t.tar.gz
    FORTRAN=intel-iforte9-9.0-*.em64t.tar.gz
elif [ $ARCH = "ia64" ] 
then
    DEBUG=intel-eidb9-9.0-*.ia64.tar.gz
    HEADER=intel-isubh9-9.0-*.ia64.tar.gz
    ICC=intel-icc9-9.0-*.ia64.tar.gz
    FORTRAN=intel-ifort9-9.0-*.ia64.tar.gz
fi 
    

# WHERE ARE THE TAR BALLS?
SRCDIR=`pwd`

# CHECK THE INSTALL DIRECTORY EXISTS AND IS WRITEABLE, THEN MV TO IT
if [ -d $INSTALLDIR -a -w $INSTALLDIR ] 
then
    echo "INSTALLDIR set to $INSTALLDIR"
else
    echo "Can't install in the area $INSTALLDIR."
    echo "Make sure it exists and is writable"
    exit 
fi
echo "Moving from $SRCDIR to $INSTALLDIR"
cd $INSTALLDIR

# CHECK THE TAR BALLS ARE IN PLACE
if [ ! -e $SRCDIR/$DEBUG ]
then
    echo "Check the debugger tar ball has been selected and exists"
    exit
else 
    echo "Debugger tar ball  selected is $DEBUG"
fi
if [ $INSTALLC = "yes" ] 
then
    if [ ! -e $SRCDIR/$HEADER ]
    then
	echo "Check the header tar ball has been selected and exists"
	exit
    else 
	echo "Header tar ball selected is $HEADER"
    fi
    if [ ! -e $SRCDIR/$ICC ]
    then
	echo "Check the icc tar ball has been selected and exists"
	exit
    else 
	echo "icc tar ball selected is $ICC"
    fi
fi

if [ $INSTALLF = "yes" ]
then
    if [ ! -e $SRCDIR/$FORTRAN ]
    then
	echo "Check the Fotran tarball has been selected and exists"
	exit
    else 
	echo "ifort tar ball selected is $FORTRAN"
    fi
fi


# EXTRACT THE TAR BALLS

echo "Unpacking software..."
tar xfz $SRCDIR/$DEBUG
if [ $INSTALLC = "yes" ]
then
    tar xfz $SRCDIR/$HEADER 
    tar xfz $SRCDIR/$ICC 
fi
if [ $INSTALLF = "yes" ]
then
    tar xfz $SRCDIR/$FORTRAN
fi
echo "Unpacking done."



# NOW FIX THE TEXT FILES IN THE BIN AREA TO CORRECT INSTALL DIR

if [ $INSTALLC = "yes" ]
then
    if [ $ARCH == ia64 ] 
    then
	cd $INSTALLDIR/intel/cc/9.0/
    elif [ $ARCH == em64t ]
    then
	cd $INSTALLDIR/intel/cce/9.0/
    elif [ $ARCH == i386 ]
    then
	cd $INSTALLDIR/intel/cc/9.0/
    fi
    for i in $(file bin/* |grep text|cut -f1 -d:)
    do
      mv $i $i.orig
      sed "s:<INSTALLDIR>:$(pwd):g" $i.orig > $i
    done
    cd ./bin
    chmod +x icc iccvars.sh iccvars.csh uninstall.sh
    rm *.orig
fi

if [ $INSTALLF = "yes" ]
then
    if [ $ARCH == ia64 ] 
    then
	cd $INSTALLDIR/intel/fc/9.0/
    elif [ $ARCH == em64t ]
    then
	cd $INSTALLDIR/intel/fce/9.0/
    elif [ $ARCH == i386 ]
    then
	cd $INSTALLDIR/intel/fc/9.0/
    fi
    for i in $(file bin/* |grep text|cut -f1 -d:)
    do
      mv $i $i.orig
      sed "s:<INSTALLDIR>:$(pwd):g" $i.orig > $i
    done
    cd ./bin
    chmod +x ifort ifortvars.sh ifortvars.csh uninstall.sh
    rm *.orig
fi
    
# REMINDER FOR THE USER

echo ""
echo "Installation complete"
echo ""
echo "You must now set your environment by running the appropriate"
echo "shell scripts. See the INSTALL file for more details."
echo ""
echo "Report problems to the OSC staff - support@osc.ox.ac.uk"
echo ""
echo ""



